@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Triangulation_2/include/CGAL/Constrained_triangulation_plus_2.h $
-// $Id: Constrained_triangulation_plus_2.h 561cc66 2022-06-29T12:30:35+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Triangulation_2/include/CGAL/Constrained_triangulation_plus_2.h $
+// $Id: include/CGAL/Constrained_triangulation_plus_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,12 +18,11 @@
 #include <CGAL/disable_warnings.h>
 
 #include <CGAL/Unique_hash_map.h>
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/Polygon_2.h>
 #include <CGAL/Triangulation_2/internal/Polyline_constraint_hierarchy_2.h>
 #include <CGAL/Triangulation_2/internal/CTP2_subconstraint_graph.h>
 #include <boost/tuple/tuple.hpp>
-#include <boost/type_traits/is_same.hpp>
 
 #include <CGAL/Default.h>
 #include <CGAL/Constrained_Delaunay_triangulation_2.h>
@@ -31,6 +30,7 @@
 #include <CGAL/Triangulation_2/insert_constraints.h>
 #include <boost/container/flat_set.hpp>
 
+#include <type_traits>
 
 namespace CGAL {
 
@@ -129,6 +129,10 @@ public:
   using Triangulation::is_infinite;
   using Triangulation::number_of_vertices;
 #endif
+#ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
+  using Triangulation::display_vertex;
+#endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
+
 
   typedef typename Triangulation::Edge             Edge;
   typedef typename Triangulation::Vertex           Vertex;
@@ -232,7 +236,7 @@ public:
      , hierarchy(Vh_less_xy(this))
   {
     insert_constraints(first, last);
-    CGAL_triangulation_postcondition( this->is_valid() );
+    CGAL_postcondition( this->is_valid() );
   }
 
 
@@ -242,7 +246,7 @@ public:
      , hierarchy(Vh_less_xy(this))
   {
     insert_constraints(constraints.begin(), constraints.end());
-    CGAL_triangulation_postcondition( this->is_valid() );
+    CGAL_postcondition( this->is_valid() );
   }
   //Helping
   void clear() { Base::clear(); hierarchy.clear(); }
@@ -275,8 +279,8 @@ public:
   {
 #ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
   std::cerr << CGAL::internal::cdt_2_indent_level
-            << "CT_plus_2::insert_constraint( #" << va->time_stamp() << "= " << va->point()
-            << " , #" << vb->time_stamp() << "= " << vb->point()
+            << "CT_plus_2::insert_constraint( " << display_vertex(va)
+            << " , " << display_vertex(vb)
             << " )\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
     // protects against inserting a zero length constraint
@@ -578,7 +582,7 @@ public:
       insert_incident_faces(vcit, out);
     }
     //AF    vertices_in_constraint_begin(ca)->fixed() = true;
-    // Vertices_in_constraint_iterator end = boost::prior(vertices_in_constraint_end(ca));
+    // Vertices_in_constraint_iterator end = std::prev(vertices_in_constraint_end(ca));
     // end->fixed() = true;
     fc.write_faces(out);
 
@@ -749,8 +753,8 @@ public:
 
   void simplify(Vertices_in_constraint_iterator v)
   {
-    Vertices_in_constraint_iterator u = boost::prior(v);
-    Vertices_in_constraint_iterator w = boost::next(v);
+    Vertices_in_constraint_iterator u = std::prev(v);
+    Vertices_in_constraint_iterator w = std::next(v);
     bool unew = (*u != *w);
     hierarchy.simplify(u,v,w);
 
@@ -883,13 +887,13 @@ insert_subconstraint(Vertex_handle vaa,
 {
 #ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
   std::cerr << CGAL::internal::cdt_2_indent_level
-            << "CT_plus_2::insert_subconstraint( #" << vaa->time_stamp() << "= " << vaa->point()
-            << " , #" << vbb->time_stamp() << "= " << vbb->point()
+            << "CT_plus_2::insert_subconstraint( " << display_vertex(vaa)
+            << " , " << display_vertex(vbb)
             << " )\n";
   internal::Indentation_level::Exit_guard exit_guard = CGAL::internal::cdt_2_indent_level.open_new_scope();
   std::cerr << CGAL::internal::cdt_2_indent_level
-            << "CT_plus_2::insert_constraint stack push [va, vb] ( #" << vaa->time_stamp() << "= " << vaa->point()
-            << " , #" << vbb->time_stamp() << "= " << vbb->point()
+            << "CT_plus_2::insert_constraint stack push [va, vb] ( " << display_vertex(vaa)
+            << " , " << display_vertex(vbb)
             << " )\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
   std::stack<std::pair<Vertex_handle, Vertex_handle> > stack;
@@ -898,11 +902,11 @@ insert_subconstraint(Vertex_handle vaa,
   while(! stack.empty()){
     boost::tie(vaa,vbb) = stack.top();
     stack.pop();
-    CGAL_triangulation_precondition( vaa != vbb);
+    CGAL_precondition( vaa != vbb);
 #ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
     std::cerr << CGAL::internal::cdt_2_indent_level
-              << "CT_plus_2::insert_subconstraint, stack pop=( #" << vaa->time_stamp() << "= " << vaa->point()
-              << " , #" << vbb->time_stamp() << "= " << vbb->point()
+              << "CT_plus_2::insert_subconstraint, stack pop=( " << display_vertex(vaa)
+              << " , " << display_vertex(vbb)
               << " ) remaining stack size: "
               << stack.size() << '\n';
     CGAL_assertion(this->is_valid());
@@ -914,8 +918,8 @@ insert_subconstraint(Vertex_handle vaa,
     if(this->includes_edge(vaa,vbb,vi,fr,i)) {
 #ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
     std::cerr << CGAL::internal::cdt_2_indent_level
-              << "CT_plus_2::insert_subconstraint, the segment ( #" << vaa->time_stamp() << "= " << vaa->point()
-              << " , #" << vbb->time_stamp() << "= " << vbb->point()
+              << "CT_plus_2::insert_subconstraint, the segment ( " << display_vertex(vaa)
+              << " , " << display_vertex(vbb)
               << " ) is an edge with #"
               << vi->time_stamp() << "= " << vi->point()
               << '\n';
@@ -925,8 +929,8 @@ insert_subconstraint(Vertex_handle vaa,
         hierarchy.split_constraint(vaa,vbb,vi);
 #ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
   std::cerr << CGAL::internal::cdt_2_indent_level
-            << "CT_plus_2::insert_constraint (includes_edge) stack push [vi, vbb] ( #" << vi->time_stamp() << "= " << vi->point()
-            << " , #" << vbb->time_stamp() << "= " << vbb->point()
+            << "CT_plus_2::insert_constraint (includes_edge) stack push [vi, vbb] ( " << display_vertex(vi)
+            << " , " << display_vertex(vbb)
             << " )\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
         stack.push(std::make_pair(vi,vbb));
@@ -949,12 +953,12 @@ insert_subconstraint(Vertex_handle vaa,
         hierarchy.split_constraint(vaa,vbb,vi);
 #ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
   std::cerr << CGAL::internal::cdt_2_indent_level
-            << "CT_plus_2::insert_constraint stack push [vaa, vi] ( #" << vaa->time_stamp() << "= " << vaa->point()
-            << " , #" << vi->time_stamp() << "= " << vi->point()
+            << "CT_plus_2::insert_constraint stack push [vaa, vi] ( " << display_vertex(vaa)
+            << " , " << display_vertex(vi)
             << " )\n";
   std::cerr << CGAL::internal::cdt_2_indent_level
-            << "CT_plus_2::insert_constraint stack push [vi, vbb] ( #" << vi->time_stamp() << "= " << vi->point()
-            << " , #" << vbb->time_stamp() << "= " << vbb->point()
+            << "CT_plus_2::insert_constraint stack push [vi, vbb] ( " << display_vertex(vi)
+            << " , " << display_vertex(vbb)
             << " )\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
         stack.push(std::make_pair(vaa,vi));
@@ -963,8 +967,8 @@ insert_subconstraint(Vertex_handle vaa,
       else {
 #ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
   std::cerr << CGAL::internal::cdt_2_indent_level
-            << "CT_plus_2::insert_constraint stack push [vaa, vbb]( #" << vaa->time_stamp() << "= " << vaa->point()
-            << " , #" << vbb->time_stamp() << "= " << vbb->point()
+            << "CT_plus_2::insert_constraint stack push [vaa, vbb]( " << display_vertex(vaa)
+            << " , " << display_vertex(vbb)
             << " )\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
         stack.push(std::make_pair(vaa,vbb));
@@ -1055,7 +1059,7 @@ copy_triangulation(const Constrained_triangulation_plus_2 &ctp)
   Vertex_iterator vit = ctp.vertices_begin();
   Vertex_iterator vvit = this->vertices_begin();
   for( ; vit != ctp.vertices_end(); ++vit, ++vvit) {
-    CGAL_triangulation_assertion(vit->point() == vvit->point());
+    CGAL_assertion(vit->point() == vvit->point());
     vmap[vit] = vvit;
   }
   hierarchy.copy(ctp.hierarchy, vmap);
@@ -1092,7 +1096,7 @@ insert(const Point& a, Locate_type lt, Face_handle loc, int li)
 
   if ( lt == Triangulation::EDGE && loc->is_constrained(li) )
   {
-    if(boost::is_same<typename Tr::Itag, No_constraint_intersection_tag>::value)
+    if(std::is_same<typename Tr::Itag, No_constraint_intersection_tag>::value)
       throw typename Tr::Intersection_of_constraints_exception();
 
     insert_in_constrained_edge = true;
@@ -1167,12 +1171,12 @@ intersect(Face_handle f, int i,
   Vertex_handle  vcc, vdd;
   vcc = f->vertex(cw(i));
   vdd = f->vertex(ccw(i));
-  CGAL_triangulation_assertion_code( bool b1 = )
+  CGAL_assertion_code( bool b1 = )
   hierarchy.enclosing_constraint(vcc,vdd,vc,vd);
-  CGAL_triangulation_assertion_code( bool b2 = )
+  CGAL_assertion_code( bool b2 = )
   hierarchy.enclosing_constraint(vaa,vbb,va,vb);
-  CGAL_triangulation_assertion(b1);
-  CGAL_triangulation_assertion(b2);
+  CGAL_assertion(b1);
+  CGAL_assertion(b2);
 
   const Point& pa = va->point();
   const Point& pb = vb->point();
@@ -1180,23 +1184,23 @@ intersect(Face_handle f, int i,
   const Point& pd = vd->point();
 #ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
   std::cerr << CGAL::internal::cdt_2_indent_level
-            << "CT_plus_2::intersect segment ( #" << va->time_stamp() << "= " << va->point()
-            << " , #" << vb->time_stamp() << "= " << vb->point()
+            << "CT_plus_2::intersect segment ( " << display_vertex(va)
+            << " , " << display_vertex(vb)
             << " ) with edge ( #"<< vc->time_stamp() << "= " << vc->point()
-            << " , #" << vd->time_stamp() << "= " << vd->point()
+            << " , " << display_vertex(vd)
             << " , Exact_intersections_tag)\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
   Point pi(ORIGIN); // initialize although we are sure that it will be
                     // set by the intersection, but to quiet a warning
   Intersection_tag itag = Intersection_tag();
-  CGAL_triangulation_assertion_code( bool ok = )
+  CGAL_assertion_code( bool ok = )
   intersection(geom_traits(), pa, pb, pc, pd, pi, itag );
-  CGAL_triangulation_assertion(ok);
+  CGAL_assertion(ok);
 
   Vertex_handle vi = insert(pi, Triangulation::EDGE, f, i);
 #ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
   std::cerr << CGAL::internal::cdt_2_indent_level
-            << "CT_plus_2::intersect, `vi` is ( #" << vi->time_stamp() << "= " << vi->point()
+            << "CT_plus_2::intersect, `vi` is ( " << display_vertex(vi)
             << " )\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
   return vi;
@@ -1220,10 +1224,10 @@ intersect(Face_handle f, int i,
   const Point& pd = vdd->point();
 #ifdef CGAL_CDT_2_DEBUG_INTERSECTIONS
   std::cerr << CGAL::internal::cdt_2_indent_level
-            << "CT_plus_2::intersect segment ( #" << vaa->time_stamp() << "= " << vaa->point()
-            << " , #" << vbb->time_stamp() << "= " << vbb->point()
+            << "CT_plus_2::intersect segment ( " << display_vertex(vaa)
+            << " , " << display_vertex(vbb)
             << " ) with edge ( #"<< vcc->time_stamp() << "= " << vcc->point()
-            << " , #" << vdd->time_stamp() << "= " << vdd->point()
+            << " , " << display_vertex(vdd)
             << " , Exact_predicates_tag)\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
 
