@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Surface_mesh_topology/include/CGAL/Curves_on_surface_topology.h $
-// $Id: Curves_on_surface_topology.h b58c05e 2020-08-13T17:59:32-04:00 Youmu
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Surface_mesh_topology/include/CGAL/Curves_on_surface_topology.h $
+// $Id: include/CGAL/Curves_on_surface_topology.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -34,8 +34,8 @@ public:
   // Types for shortest noncontractible cycle
   using Shortest_noncontractible_cycle=typename internal::Shortest_noncontractible_cycle<Mesh, true>;
   using Facewidth                     =typename internal::Facewidth<Mesh>;
-  using Dart_const_handle             =typename Shortest_noncontractible_cycle::Original_dart_const_handle;
-  using halfedge_descriptor           =Dart_const_handle ; // To be compatible with BGL
+  using Dart_const_descriptor             =typename Shortest_noncontractible_cycle::Original_dart_const_descriptor;
+  using halfedge_descriptor           =Dart_const_descriptor ; // To be compatible with BGL
 
   // Constructor
   Curves_on_surface_topology(const Mesh& amesh, bool /* display_time */=false) :
@@ -116,14 +116,14 @@ public:
 
   template <class WeightFunctor>
   Path_on_surface<Mesh> compute_shortest_non_contractible_cycle_with_base_point
-  (Dart_const_handle dh, const WeightFunctor& wf, bool display_time=false) const
+  (Dart_const_descriptor dh, const WeightFunctor& wf, bool display_time=false) const
   {
     compute_shortest_non_contractible_cycle_representation(display_time);
     return m_shortest_noncontractible_cycle->compute_cycle(dh, NULL, wf, display_time);
   }
 
   Path_on_surface<Mesh> compute_shortest_non_contractible_cycle_with_base_point
-  (Dart_const_handle dh, bool display_time=false) const
+  (Dart_const_descriptor dh, bool display_time=false) const
   {
     compute_shortest_non_contractible_cycle_representation(display_time);
     return m_shortest_noncontractible_cycle->compute_cycle(dh, display_time);
@@ -161,7 +161,7 @@ public:
     { m_facewidth=std::make_unique<Facewidth>(m_original_mesh, display_time); }
   }
 
-  std::vector<Dart_const_handle> compute_face_width(bool display_time=false) const
+  std::vector<Dart_const_descriptor> compute_face_width(bool display_time=false) const
   {
     compute_face_width_representation(display_time);
     return m_facewidth->compute_face_width(display_time);
@@ -181,7 +181,7 @@ public:
 // Utility functions
 
   // Set whether to display warning message in `std::cerr` when input doesn't meet
-  // prerequesite
+  // prerequisite
   void set_verbose(bool is_verbose)
   {
     m_is_verbose = is_verbose;
