@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Intersections_2/include/CGAL/Intersections_2/Circle_2_Point_2.h $
-// $Id: Circle_2_Point_2.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Intersections_2/include/CGAL/Intersections_2/Circle_2_Point_2.h $
+// $Id: include/CGAL/Intersections_2/Circle_2_Point_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -25,20 +25,19 @@ namespace internal {
 
 template <class K>
 inline
-bool
-do_intersect(const typename K::Point_2 &pt,
-             const typename K::Circle_2 &circle,
+typename K::Boolean
+do_intersect(const typename K::Point_2& pt,
+             const typename K::Circle_2& circle,
              const K&)
 {
   return circle.has_on_boundary(pt);
 }
 
-
 template <class K>
 inline
-bool
-do_intersect(const typename K::Circle_2 &circle,
-             const typename K::Point_2 &pt,
+typename K::Boolean
+do_intersect(const typename K::Circle_2& circle,
+             const typename K::Point_2& pt,
              const K&)
 {
   return circle.has_on_boundary(pt);
@@ -48,8 +47,8 @@ do_intersect(const typename K::Circle_2 &circle,
 template <class K>
 typename CGAL::Intersection_traits
 <K, typename K::Point_2, typename K::Circle_2>::result_type
-intersection(const typename K::Point_2 &pt,
-             const typename K::Circle_2 &circle,
+intersection(const typename K::Point_2& pt,
+             const typename K::Circle_2& circle,
              const K& k)
 {
   if (do_intersect(pt,circle, k))
@@ -60,8 +59,8 @@ intersection(const typename K::Point_2 &pt,
 template <class K>
 typename CGAL::Intersection_traits
 <K, typename K::Circle_2, typename K::Point_2>::result_type
-intersection(const typename K::Circle_2 &circle,
-             const typename K::Point_2 &pt,
+intersection(const typename K::Circle_2& circle,
+             const typename K::Point_2& pt,
              const K& k)
 {
   return internal::intersection(pt, circle, k);
@@ -73,5 +72,6 @@ intersection(const typename K::Circle_2 &circle,
 CGAL_INTERSECTION_FUNCTION(Point_2, Circle_2, 2)
 CGAL_DO_INTERSECT_FUNCTION(Circle_2, Point_2, 2)
 
-} //namespace CGAL
+} // namespace CGAL
+
 #endif // CGAL_INTERSECTIONS_2_POINT_2_CIRCLE_2_H
