@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/LEDA/include/CGAL/LEDA_basic.h $
-// $Id: LEDA_basic.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/LEDA/include/CGAL/LEDA_basic.h $
+// $Id: include/CGAL/LEDA_basic.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -25,8 +25,14 @@
 // The following is needed for LEDA 4.4 due to min/max problems...
 #  define LEDA_NO_MIN_MAX_TEMPL
 
+#ifdef CGAL_CXX20
+#  define STREAM_DUMMY // disable stream_dummy() function that is not used and using features removed from c++20
+// We cannot undef STREAM_DUMMY as LEDA/internal/PREAMBULE.h is not protected
+#endif
 #include <LEDA/system/basic.h>
 
+
+
 #ifdef LEDA_NAMESPACE
 #  define CGAL_LEDA_SCOPE  leda
 #else
