@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Mesh_3/include/CGAL/Mesh_3/Triangulation_sizing_field.h $
-// $Id: Triangulation_sizing_field.h cbfeb98 2022-10-05T15:39:04+02:00 Sebastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Mesh_3/include/CGAL/Mesh_3/Triangulation_sizing_field.h $
+// $Id: include/CGAL/Mesh_3/Triangulation_sizing_field.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -43,18 +43,18 @@ template <typename Tr>
 class Triangulation_sizing_field
 {
   // Types
-  typedef typename Tr::Geom_traits                        Gt;
+  typedef typename Tr::Geom_traits                        GT;
   typedef typename Tr::Bare_point                         Bare_point;
   typedef typename Tr::Weighted_point                     Weighted_point;
-  typedef typename Gt::FT                                 FT;
+  typedef typename GT::FT                                 FT;
 
-  typedef Triangulation_vertex_base_with_info_3<FT, Gt>   Vbb;
-  typedef Regular_triangulation_vertex_base_3<Gt, Vb>     Vb;
-  typedef Triangulation_cell_base_3<Gt>                   Cbb;
+  typedef Triangulation_vertex_base_with_info_3<FT, GT>   Vbb;
+  typedef Regular_triangulation_vertex_base_3<GT, Vb>     Vb;
+  typedef Triangulation_cell_base_3<GT>                   Cbb;
   typedef Regular_triangulation_cell_base_3<
-            Gt, Cbb, Discard_hidden_points>               Cb;
+            GT, Cbb, Discard_hidden_points>               Cb;
   typedef Triangulation_data_structure_3<Vb, Cb>          Tds;
-  typedef Regular_triangulation_3<Gt,Tds>                 Compact_triangulation;
+  typedef Regular_triangulation_3<GT,Tds>                 Compact_triangulation;
   typedef Compact_triangulation                           Ctr;
 
   typedef typename Tr::Vertex_handle                      Vertex_handle;
@@ -181,8 +181,8 @@ typename Triangulation_sizing_field<Tr>::FT
 Triangulation_sizing_field<Tr>::
 interpolate_on_cell_vertices(const Weighted_point& p, const CCell_handle& cell) const
 {
-  typename Gt::Construct_point_3 cp = ctr_.geom_traits().construct_point_3_object();
-  typename Gt::Compute_volume_3 volume = ctr_.geom_traits().compute_volume_3_object();
+  typename GT::Construct_point_3 cp = ctr_.geom_traits().construct_point_3_object();
+  typename GT::Compute_volume_3 volume = ctr_.geom_traits().compute_volume_3_object();
 
   // Interpolate value using tet vertices values
   const FT& va = cell->vertex(0)->info();
@@ -217,8 +217,8 @@ typename Triangulation_sizing_field<Tr>::FT
 Triangulation_sizing_field<Tr>::
 interpolate_on_facet_vertices(const Weighted_point& p, const CCell_handle& cell) const
 {
-  typename Gt::Construct_point_3 cp = ctr_.geom_traits().construct_point_3_object();
-  typename Gt::Compute_area_3 area = ctr_.geom_traits().compute_area_3_object();
+  typename GT::Construct_point_3 cp = ctr_.geom_traits().construct_point_3_object();
+  typename GT::Compute_area_3 area = ctr_.geom_traits().compute_area_3_object();
 
   // Find infinite vertex and put it in k0
   int k0 = 0;
