@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Mesh_3/include/CGAL/Mesh_3/mesh_standard_facet_criteria.h $
-// $Id: mesh_standard_facet_criteria.h 58b10a3 2020-03-26T18:58:50+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Mesh_3/include/CGAL/Mesh_3/mesh_standard_facet_criteria.h $
+// $Id: include/CGAL/Mesh_3/mesh_standard_facet_criteria.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -102,14 +102,14 @@ protected:
     CGAL_assertion (f.first->is_facet_on_surface(f.second));
     CGAL_assertion (B_ != 0);
 
-    typedef typename Tr::Geom_traits      Gt;
+    typedef typename Tr::Geom_traits      GT;
     typedef typename Tr::Bare_point       Bare_point;
     typedef typename Tr::Weighted_point   Weighted_point;
 
-    typedef typename Gt::Compute_squared_area_3     Area;
-    typedef typename Gt::Compute_squared_distance_3 Distance;
-    typedef typename Gt::Construct_point_3          Construct_point_3;
-    typedef typename Gt::Construct_triangle_3       Construct_triangle_3;
+    typedef typename GT::Compute_squared_area_3     Area;
+    typedef typename GT::Compute_squared_distance_3 Distance;
+    typedef typename GT::Construct_point_3          Construct_point_3;
+    typedef typename GT::Construct_triangle_3       Construct_triangle_3;
 
     Area area = tr.geom_traits().compute_squared_area_3_object();
     Distance distance = tr.geom_traits().compute_squared_distance_3_object();
@@ -127,7 +127,7 @@ protected:
     const FT d12 = distance(p1,p2);
     const FT d13 = distance(p1,p3);
     const FT d23 = distance(p2,p3);
-    const FT min_d123 = details::min_3<Gt>(d12,d13,d23);
+    const FT min_d123 = details::min_3<GT>(d12,d13,d23);
 
     const FT aspect_ratio = 4 * triangle_area * min_d123 / (d12*d13*d23);
 
@@ -193,11 +193,11 @@ protected:
     CGAL_assertion(f.first->is_facet_on_surface(f.second));
     CGAL_assertion (B_ != 0);
 
-    typedef typename Tr::Geom_traits    Gt;
+    typedef typename Tr::Geom_traits    GT;
     typedef typename Tr::Weighted_point Weighted_point;
     typedef typename Tr::Bare_point Bare_point;
 
-    typename Gt::Construct_weighted_circumcenter_3 weighted_circumcenter =
+    typename GT::Construct_weighted_circumcenter_3 weighted_circumcenter =
         tr.geom_traits().construct_weighted_circumcenter_3_object();
 
     const Weighted_point& p1 = tr.point(f.first, (f.second+1)&3);
@@ -264,11 +264,11 @@ protected:
   {
     CGAL_assertion (f.first->is_facet_on_surface(f.second));
 
-    typedef typename Tr::Geom_traits    Gt;
+    typedef typename Tr::Geom_traits    GT;
     typedef typename Tr::Weighted_point Weighted_point;
     typedef typename Tr::Bare_point Bare_point;
 
-    typename Gt::Construct_weighted_circumcenter_3 weighted_circumcenter =
+    typename GT::Construct_weighted_circumcenter_3 weighted_circumcenter =
       tr.geom_traits().construct_weighted_circumcenter_3_object();
 
     const Weighted_point& p1 = tr.point(f.first, (f.second+1)&3);
@@ -346,11 +346,11 @@ protected:
   {
     CGAL_assertion (f.first->is_facet_on_surface(f.second));
 
-    typedef typename Tr::Geom_traits    Gt;
+    typedef typename Tr::Geom_traits    GT;
     typedef typename Tr::Bare_point     Bare_point;
     typedef typename Tr::Weighted_point Weighted_point;
 
-    typename Gt::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
+    typename GT::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
 
     const Weighted_point& wp1 = tr.point(f.first, (f.second+1)&3);
     const Bare_point& p1 = cp(wp1);
@@ -398,7 +398,16 @@ private:
 public:
   // Nb: the default bound of the criterion is such that the criterion
   // is always fulfilled
-  Uniform_size_criterion(const FT b = 1e20) : B_(b * b) {}
+  Uniform_size_criterion(const FT b = 1e20,
+                         const bool is_lower_bound = false)
+   : B_(b * b)
+   , is_lower_bound_(is_lower_bound)
+   {}
+
+  bool is_lower_bound() const
+  {
+    return is_lower_bound_;
+  }
 
 protected:
   virtual void do_accept(Visitor_& v) const
@@ -417,11 +426,11 @@ protected:
     CGAL_assertion (f.first->is_facet_on_surface(f.second));
     CGAL_assertion (B_ != 0);
 
-    typedef typename Tr::Geom_traits        Gt;
+    typedef typename Tr::Geom_traits        GT;
     typedef typename Tr::Bare_point         Bare_point;
     typedef typename Tr::Weighted_point     Weighted_point;
 
-    typename Gt::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
+    typename GT::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
 
     const Weighted_point& wp1 = tr.point(f.first, (f.second+1)&3);
     const Bare_point p1 = cp(wp1);
@@ -429,11 +438,19 @@ protected:
 
     const FT sq_radius = tr.min_squared_distance(p1, ball_center);
 
-    if ( sq_radius > B_ )
+    if (!is_lower_bound() && sq_radius > B_ )
     {
 #ifdef CGAL_MESH_3_DEBUG_FACET_CRITERIA
       std::cerr << "Bad facet (uniform size): sq_radius[" << sq_radius
                 << "] bound[" << B_ << "]\n";
+#endif
+      return Is_bad(Quality(B_/sq_radius));
+    }
+    else if(is_lower_bound() && sq_radius <= B_)
+    {
+#ifdef CGAL_MESH_3_DEBUG_FACET_CRITERIA
+      std::cerr << "Facet too small (uniform size): sq_radius[" << sq_radius
+      << "] bound[" << B_ << "]\n";
 #endif
       return Is_bad(Quality(B_/sq_radius));
     }
@@ -443,6 +460,7 @@ protected:
 
 private:
   FT B_;
+  const bool is_lower_bound_;
 
 };  // end Uniform_size_criterion
 
@@ -635,15 +653,8 @@ class Facet_criterion_visitor_with_features
   typedef Mesh_3::Criterion_visitor<Tr, typename Tr::Facet> Base;
   typedef Facet_criterion_visitor_with_features<Tr> Self;
 
-  typedef Mesh_3::Abstract_criterion<Tr, Self>                Criterion;
-  typedef Mesh_3::Curvature_size_criterion<Tr, Self>          Curvature_size_criterion;
-  typedef Mesh_3::Aspect_ratio_criterion<Tr, Self>            Aspect_ratio_criterion;
-  typedef Mesh_3::Facet_on_surface_criterion<Tr, Self>        Facet_on_surface_criterion;
-  typedef Mesh_3::Facet_size_criterion<Tr, Self>              Facet_size_criterion;
-  typedef Mesh_3::Facet_on_same_surface_criterion<Tr, Self>   Facet_on_same_surface_criterion;
-
-  typedef typename Tr::Geom_traits  Gt;
-  typedef typename Gt::FT           FT;
+  typedef typename Tr::Geom_traits  GT;
+  typedef typename GT::FT           FT;
 
 public:
   typedef typename Base::Quality  Facet_quality;
@@ -661,15 +672,15 @@ public:
     , angle_ratio_(0.5*0.5*4.)
     , size_ratio_(0.4*0.4*4.)
   {
-    typedef typename Tr::Geom_traits    Gt;
+    typedef typename Tr::Geom_traits    GT;
     typedef typename Tr::Weighted_point Weighted_point;
     typedef typename Tr::Cell_handle    Cell_handle;
 
-    typename Gt::Compute_squared_radius_smallest_orthogonal_sphere_3 sq_radius =
+    typename GT::Compute_squared_radius_smallest_orthogonal_sphere_3 sq_radius =
       tr.geom_traits().compute_squared_radius_smallest_orthogonal_sphere_3_object();
-    typename Gt::Compute_weight_3 cw =
+    typename GT::Compute_weight_3 cw =
       tr.geom_traits().compute_weight_3_object();
-    typename Gt::Compare_weighted_squared_radius_3 compare =
+    typename GT::Compare_weighted_squared_radius_3 compare =
       tr.geom_traits().compare_weighted_squared_radius_3_object();
 
     const Cell_handle& c = fh.first;
@@ -736,11 +747,9 @@ public:
     }
   }
 
-  // Destructor
-  ~Facet_criterion_visitor_with_features() {}
-
   // visit functions
-  void visit(const Criterion& criterion)
+  template<typename T, typename V>
+  void visit(const Mesh_3::Abstract_criterion<T, V>& criterion)
   {
     if ( 3 == wp_nb_ && do_spheres_intersect_ )
     {
@@ -751,7 +760,8 @@ public:
     Base::do_visit(criterion);
   }
 
-  void visit(const Curvature_size_criterion& criterion)
+  template<typename T, typename V>
+  void visit(const Mesh_3::Curvature_size_criterion<T, V>& criterion)
   {
     if (   ratio_ < approx_ratio_
         && (do_spheres_intersect_ || 1 == wp_nb_ ) )
@@ -763,7 +773,8 @@ public:
     Base::do_visit(criterion);
   }
 
-  void visit(const Aspect_ratio_criterion& criterion)
+  template<typename T, typename V>
+  void visit(const Mesh_3::Aspect_ratio_criterion<T, V>& criterion)
   {
     if (   ratio_ < angle_ratio_
         && (do_spheres_intersect_ || 1 == wp_nb_) )
@@ -775,7 +786,8 @@ public:
     Base::do_visit(criterion);
   }
 
-  void visit(const Facet_size_criterion& criterion)
+  template<typename T, typename V>
+  void visit(const Mesh_3::Facet_size_criterion<T, V>& criterion)
   {
     if (   ratio_ < size_ratio_
         && (do_spheres_intersect_ || 1 == wp_nb_) )
@@ -798,6 +810,74 @@ private:
 };  // end class Facet_criterion_visitor
 
 
+template <typename Tr>
+class Facet_criterion_visitor_with_radius_lower_bound
+  : public Facet_criterion_visitor_with_features<Tr>
+{
+  typedef Facet_criterion_visitor_with_features<Tr> Base;
+  typedef Facet_criterion_visitor_with_radius_lower_bound<Tr> Self;
+
+  typedef typename Tr::Geom_traits  GT;
+  typedef typename GT::FT           FT;
+
+public:
+  typedef typename Base::Quality  Facet_quality;
+  typedef typename Base::Is_bad   Is_facet_bad;
+  typedef typename Base::Handle   Handle;
+  typedef Handle                  Facet;
+
+  // Constructor
+  Facet_criterion_visitor_with_radius_lower_bound(const Tr& tr, const Facet& fh)
+    : Base(tr, fh)
+    , dont_go_further_(false)
+  {}
+
+  Is_facet_bad is_bad() const
+  {
+    if (dont_go_further_)
+      return Is_facet_bad();
+    else
+      return Base::is_bad();
+  }
+
+  bool go_further() const
+  {
+    if (dont_go_further_)
+      return false;
+    else
+      return Base::go_further();
+  }
+
+  // visit functions
+  template<typename Criterion>
+  void visit(const Criterion& criterion)
+  {
+    Base::visit(criterion);
+  }
+
+  template<typename T, typename V>
+  void visit(const Mesh_3::Abstract_criterion<T, V>& criterion)
+  {
+    Base::visit(criterion);
+  }
+
+  template<typename T, typename V>
+  void visit(const Mesh_3::Uniform_size_criterion<T, V>& criterion)
+  {
+    Base::visit(criterion);
+
+    if (criterion.is_lower_bound() && Base::is_bad())
+      dont_go_further_ = true;
+  }
+
+private:
+  bool dont_go_further_;
+
+
+};// end class Facet_criterion_visitor_with_radius_lower_bound
+
+
+
 }  // end namespace Mesh_3
 
 }  // end namespace CGAL
