@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Minkowski_sum_2/include/CGAL/Minkowski_sum_2/AABB_traits_2.h $
-// $Id: AABB_traits_2.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Minkowski_sum_2/include/CGAL/Minkowski_sum_2/AABB_traits_2.h $
+// $Id: include/CGAL/Minkowski_sum_2/AABB_traits_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Sebastian Morr    <sebastian@morr.cc>
@@ -13,12 +13,16 @@
 #define CGAL_AABB_TRAITS_2_H
 
 #include <CGAL/license/Minkowski_sum_2.h>
+#include <CGAL/Search_traits_2.h>
 
 
 namespace CGAL {
 
+namespace Minkowski_sum {
+
 template<typename GeomTraits, typename AABB_primitive_>
 class AABB_traits_2
+  :public Search_traits_2<GeomTraits>
 {
 
 public:
@@ -37,18 +41,18 @@ public:
 
   // Types for AABB_tree
   typedef typename GeomTraits::FT FT;
-  typedef typename GeomTraits::Point_2 Point_3;
-  typedef typename GeomTraits::Circle_2 Sphere_3;
-  typedef typename GeomTraits::Iso_rectangle_2 Iso_cuboid_3;
-  typedef typename GeomTraits::Construct_center_2 Construct_center_3;
-  typedef typename GeomTraits::Construct_iso_rectangle_2 Construct_iso_cuboid_3;
-  typedef typename GeomTraits::Construct_min_vertex_2 Construct_min_vertex_3;
-  typedef typename GeomTraits::Construct_max_vertex_2 Construct_max_vertex_3;
-  typedef typename GeomTraits::Compute_squared_radius_2 Compute_squared_radius_3;
+  typedef typename GeomTraits::Point_2 Point_2;
+  typedef typename GeomTraits::Circle_2 Circle_2;
+  typedef typename GeomTraits::Iso_rectangle_2 Iso_rectangle_2;
+  typedef typename GeomTraits::Construct_center_2 Construct_center_2;
+  typedef typename GeomTraits::Construct_iso_rectangle_2 Construct_iso_cuboid_2;
+  typedef typename GeomTraits::Construct_min_vertex_2 Construct_min_vertex_2;
+  typedef typename GeomTraits::Construct_max_vertex_2 Construct_max_vertex_2;
+  typedef typename GeomTraits::Compute_squared_radius_2 Compute_squared_radius_2;
   typedef typename GeomTraits::Cartesian_const_iterator_2
-  Cartesian_const_iterator_3;
+  Cartesian_const_iterator_2;
   typedef typename GeomTraits::Construct_cartesian_const_iterator_2
-  Construct_cartesian_const_iterator_3;
+  Construct_cartesian_const_iterator_2;
 
   AABB_traits_2(const Point &translation_point): m_translation_point(
       translation_point)
@@ -214,6 +218,8 @@ private:
   }
 };
 
+} // namespace Minkowski_sum
+
 } // namespace CGAL
 
 #endif
