@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/polygon_soup_to_polygon_mesh.h $
-// $Id: polygon_soup_to_polygon_mesh.h 5a992f6 2022-11-22T10:31:34+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/polygon_soup_to_polygon_mesh.h $
+// $Id: include/CGAL/Polygon_mesh_processing/polygon_soup_to_polygon_mesh.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -21,6 +21,7 @@
 #include <CGAL/boost/graph/Euler_operations.h>
 #include <CGAL/boost/graph/iterator.h>
 #include <CGAL/boost/graph/named_params_helper.h>
+#include <CGAL/boost/graph/internal/helpers.h>
 #include <CGAL/Dynamic_property_map.h>
 #include <CGAL/property_map.h>
 
@@ -42,7 +43,7 @@ namespace internal {
 template <typename PM_Point, typename PS_Point>
 PM_Point convert_to_pm_point(const PS_Point& p)
 {
-  CGAL_static_assertion((std::is_convertible<PS_Point, PM_Point>::value));
+  static_assert(std::is_convertible<PS_Point, PM_Point>::value);
   return PM_Point(p);
 }
 
@@ -53,6 +54,18 @@ PM_Point convert_to_pm_point(const std::array<PS_FT, 3>& p)
   return PM_Point(p[0], p[1], p[2]);
 }
 
+template <class OutputIterator, typename Value_type = typename value_type_traits<OutputIterator>::type>
+struct Polygon_and_Point_id_helper
+{
+  typedef std::remove_cv_t<std::remove_reference_t<typename Value_type::first_type>> type;
+};
+
+template <class OutputIterator>
+struct Polygon_and_Point_id_helper<OutputIterator, void>
+{
+  typedef std::size_t type;
+};
+
 template <typename PointRange,
           typename PolygonRange,
           typename PointMap = typename CGAL::GetPointMap<PointRange>::const_type>
@@ -74,15 +87,21 @@ public:
       m_pm(pm)
   { }
 
-  template <typename PolygonMesh, typename VertexPointMap>
+  template <typename PolygonMesh, typename VertexPointMap,
+            typename V2V, //pointindex-2-vertex
+            typename F2F> //polygonindex-2-face
   void operator()(PolygonMesh& pmesh,
                   VertexPointMap vpm,
+                  V2V i2v,
+                  F2F i2f,
                   const bool insert_isolated_vertices = true)
   {
     typedef typename boost::graph_traits<PolygonMesh>::vertex_descriptor    vertex_descriptor;
-
     typedef typename boost::property_traits<VertexPointMap>::value_type     PM_Point;
 
+    typedef typename Polygon_and_Point_id_helper<V2V>::type Point_id;
+    typedef typename Polygon_and_Point_id_helper<F2F>::type Polygon_id;
+
     reserve(pmesh, static_cast<typename boost::graph_traits<PolygonMesh>::vertices_size_type>(m_points.size()),
             static_cast<typename boost::graph_traits<PolygonMesh>::edges_size_type>(2*m_polygons.size()),
             static_cast<typename boost::graph_traits<PolygonMesh>::faces_size_type>(m_polygons.size()));
@@ -101,7 +120,7 @@ public:
     }
 
     std::vector<vertex_descriptor> vertices(m_points.size());
-    for(std::size_t i = 0, end = m_points.size(); i < end; ++i)
+    for(Point_id i = 0, end = static_cast<Point_id>(m_points.size()); i < end; ++i)
     {
       if(!insert_isolated_vertices && !not_isolated.test(i))
         continue;
@@ -109,9 +128,10 @@ public:
       vertices[i] = add_vertex(pmesh);
       PM_Point pi = convert_to_pm_point<PM_Point>(get(m_pm, m_points[i]));
       put(vpm, vertices[i], pi);
+      *i2v++ = std::make_pair(i, vertices[i]);
     }
 
-    for(std::size_t i = 0, end = m_polygons.size(); i < end; ++i)
+    for(Polygon_id i = 0, end = static_cast<Polygon_id>(m_polygons.size()); i < end; ++i)
     {
       const Polygon& polygon = m_polygons[i];
       const std::size_t size = polygon.size();
@@ -121,9 +141,9 @@ public:
       for(std::size_t j = 0; j < size; ++j)
         vr[j] = vertices[polygon[j] ];
 
-      CGAL_assertion_code(typename boost::graph_traits<PolygonMesh>::face_descriptor fd =)
-          CGAL::Euler::add_face(vr, pmesh);
-      CGAL_assertion(fd != boost::graph_traits<PolygonMesh>::null_face());
+      typename boost::graph_traits<PolygonMesh>::face_descriptor fd = CGAL::Euler::add_face(vr, pmesh);
+      CGAL_postcondition(is_valid_face_descriptor(fd, pmesh));
+      *i2f++ = std::make_pair(i, fd);
     }
   }
 
@@ -131,7 +151,11 @@ public:
   void operator()(PolygonMesh& pmesh,
                   const bool insert_isolated_vertices = true)
   {
-    return operator()(pmesh, get(CGAL::vertex_point, pmesh), insert_isolated_vertices);
+    return operator()(pmesh,
+             get(CGAL::vertex_point, pmesh),
+             CGAL::Emptyset_iterator(),
+             CGAL::Emptyset_iterator(),
+             insert_isolated_vertices);
   }
 
 private:
@@ -143,7 +167,7 @@ private:
 } // namespace internal
 
 /**
-* \ingroup PMP_repairing_grp
+* \ingroup PMP_combinatorial_repair_grp
 *
 * \brief returns `true` if the soup of polygons defines a valid polygon
 * mesh that can be handled by
@@ -173,7 +197,7 @@ bool is_polygon_soup_a_polygon_mesh(const PolygonRange& polygons)
   typedef typename boost::range_value<PolygonRange>::type           Polygon;
   typedef typename boost::range_value<Polygon>::type                V_ID;
 
-  if(boost::begin(polygons) == boost::end(polygons))
+  if(std::begin(polygons) == std::end(polygons))
     return true;
 
   //check there is no duplicated ordered edge, and
@@ -189,7 +213,7 @@ bool is_polygon_soup_a_polygon_mesh(const PolygonRange& polygons)
       return false;
 
     polygon_vertices.clear();
-    V_ID prev = *std::prev(boost::end(polygon));
+    V_ID prev = *std::prev(std::end(polygon));
     for(V_ID id : polygon)
     {
       if(max_id<id)
@@ -221,7 +245,7 @@ bool is_polygon_soup_a_polygon_mesh(const PolygonRange& polygons)
 }
 
 /**
-* \ingroup PMP_repairing_grp
+* \ingroup PMP_combinatorial_repair_grp
 *
 * builds a polygon mesh from a soup of polygons.
 *
@@ -250,6 +274,37 @@ bool is_polygon_soup_a_polygon_mesh(const PolygonRange& polygons)
 *                    of the vertex point map associated to the polygon mesh}
 *     \cgalParamDefault{`CGAL::Identity_property_map`}
 *   \cgalParamNEnd
+*
+*  \cgalParamNBegin{point_to_vertex_output_iterator}
+*   \cgalParamDescription{an `OutputIterator` containing the pairs source-vertex-index
+*                         from `points`, target-vertex.}
+*   \cgalParamType{a class model of `OutputIterator` accepting
+*                  `std::pair<int, boost::graph_traits<PolygonMesh>::%vertex_descriptor>`}
+*   \cgalParamDefault{`Emptyset_iterator`}
+* \cgalParamNEnd
+*
+*  \cgalParamNBegin{polygon_to_face_output_iterator}
+*   \cgalParamDescription{an `OutputIterator` containing the pairs polygon-index
+*                         from `polygons`, target-face.}
+*   \cgalParamType{a class model of `OutputIterator` accepting
+*                  `std::pair<int, boost::graph_traits<PolygonMesh>::%face_descriptor>`}
+*   \cgalParamDefault{`Emptyset_iterator`}
+* \cgalParamNEnd
+*
+*  \cgalParamNBegin{point_to_vertex_map}
+*   \cgalParamDescription{a property map associating each soup point of `points` to a vertex of `out`.}
+*   \cgalParamType{a class model of `ReadablePropertyMap` with an integer type as key type and
+*                  `boost::graph_traits<PolygonMesh>::%vertex_descriptor` as value type.}
+*   \cgalParamDefault{unused}
+* \cgalParamNEnd
+*
+*  \cgalParamNBegin{polygon_to_face_map}
+*   \cgalParamDescription{a property map associating each soup polygon of `polygons` to a face of `out`}
+*   \cgalParamType{a class model of `ReadablePropertyMap` with an integer type as key type and
+*                  `boost::graph_traits<PolygonMesh>::%face_descriptor` as value type.}
+*   \cgalParamDefault{unused}
+* \cgalParamNEnd
+*
 * \cgalNamedParamsEnd
 *
 * @param np_pm an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
@@ -292,7 +347,18 @@ void polygon_soup_to_polygon_mesh(const PointRange& points,
                                           get_property_map(CGAL::vertex_point, out));
 
   internal::PS_to_PM_converter<PointRange, PolygonRange, Point_map> converter(points, polygons, pm);
-  converter(out, vpm);
+  converter(out, vpm,
+    choose_parameter(get_parameter(np_ps, internal_np::point_to_vertex_output_iterator),
+                     impl::make_functor(get_parameter(np_ps, internal_np::point_to_vertex_map))),
+    choose_parameter(get_parameter(np_ps, internal_np::polygon_to_face_output_iterator),
+                     impl::make_functor(get_parameter(np_ps, internal_np::polygon_to_face_map))));
+
+  static_assert(
+      (parameters::is_default_parameter<NamedParameters_PS,internal_np::vertex_to_vertex_map_t>::value),
+      "Named parameter vertex_to_vertex_map was renamed point_to_vertex_map");
+  static_assert(
+      (parameters::is_default_parameter<NamedParameters_PS,internal_np::face_to_face_map_t>::value),
+      "Named parameter face_to_face_map was renamed polygon_to_face_map");
 }
 
 } // namespace Polygon_mesh_processing
