@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Polyhedron/include/CGAL/Polyhedron_3.h $
-// $Id: Polyhedron_3.h 3ad94a7 2022-05-17T12:04:52+01:00 Andreas Fabri
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polyhedron/include/CGAL/Polyhedron_3.h $
+// $Id: include/CGAL/Polyhedron_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -855,6 +855,10 @@ public:
 
     Facet_iterator facets_end() { return hds_.faces_end();}
 
+    // added for convenience
+    Facet_iterator faces_begin() { return hds_.faces_begin();}
+    Facet_iterator faces_end() { return hds_.faces_end();}
+
     Facet_handles facet_handles() {
         return make_prevent_deref_range(facets_begin(), facets_end());
     }
@@ -886,11 +890,15 @@ public:
     Facet_const_iterator facets_begin() const { return hds_.faces_begin();}
     Facet_const_iterator facets_end()   const { return hds_.faces_end();}
 
+    // added for convenience
+    Facet_const_iterator faces_begin() const { return hds_.faces_begin();}
+    Facet_const_iterator faces_end()   const { return hds_.faces_end();}
+
     Facet_const_handles facet_handles() const {
         return make_prevent_deref_range(facets_begin(), facets_end());
     }
 
-    // Auxiliary iterators for convinience
+    // Auxiliary iterators for convenience
     Point_iterator       points_begin()       { return vertices_begin();}
     Point_iterator       points_end()         { return vertices_end();}
 
@@ -1302,7 +1310,7 @@ public:
         // Three copies of the vertices and two new triangles will be
         // created. h,i,j will be incident to the first new triangle. The
         // returnvalue will be an halfedge iterator denoting the new
-        // halfegdes of the second new triangle which was h beforehand.
+        // halfedges of the second new triangle which was h beforehand.
         // Precondition: h,i,j are distinct, consecutive vertices of the
         // polyhedron and form a cycle: i.e. `h->vertex() == i->opposite()
         // ->vertex()', ..., `j->vertex() == h->opposite()->vertex()'. The
@@ -1465,7 +1473,7 @@ public:
         // removes all vertices, halfedges, and facets.
 
     void erase_all() { clear(); }
-        // equivalent to `clear()'. Depricated.
+        // equivalent to `clear()'. Deprecated.
 
 // Special Operations on Polyhedral Surfaces
 
@@ -1583,7 +1591,7 @@ public:
                      << std::endl;
                 break;
             }
-            // Distinct facets on each side of an halfegde.
+            // Distinct facets on each side of an halfedge.
             valid = valid && ( ! check_tag( Supports_halfedge_face()) ||
                                D.get_face(i) != D.get_face(i->opposite()));
             if ( ! valid) {
