@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Triangulation_3/include/CGAL/Regular_triangulation_cell_base_3.h $
-// $Id: Regular_triangulation_cell_base_3.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Triangulation_3/include/CGAL/Regular_triangulation_cell_base_3.h $
+// $Id: include/CGAL/Regular_triangulation_cell_base_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Christophe Delage <christophe.delage@sophia.inria.fr>
@@ -21,10 +21,8 @@
 #include <CGAL/Hidden_point_memory_policy.h>
 #include <CGAL/Triangulation_cell_base_3.h>
 
-#include <boost/type_traits/is_same.hpp>
-#include <boost/utility/enable_if.hpp>
-
 #include <list>
+#include <type_traits>
 
 namespace CGAL {
 
@@ -96,47 +94,47 @@ public:
 
   // Memory_policy is Tag_true -------------------------------------------------
   template<typename Tag>
-  Point_iterator hidden_points_begin_internal(typename boost::enable_if_c<Tag::value>::type* = nullptr)
+  Point_iterator hidden_points_begin_internal(std::enable_if_t<Tag::value>* = nullptr)
   {  return _hidden.begin(); }
   template<typename Tag>
-  Point_iterator hidden_points_end_internal(typename boost::enable_if_c<Tag::value>::type* = nullptr)
+  Point_iterator hidden_points_end_internal(std::enable_if_t<Tag::value>* = nullptr)
   { return _hidden.end(); }
 
   template<typename Tag>
-  Point_const_iterator hidden_points_begin_internal(typename boost::enable_if_c<Tag::value>::type* = nullptr) const
+  Point_const_iterator hidden_points_begin_internal(std::enable_if_t<Tag::value>* = nullptr) const
   { return _hidden.begin(); }
   template<typename Tag>
-  Point_const_iterator hidden_points_end_internal(typename boost::enable_if_c<Tag::value>::type* = nullptr) const
+  Point_const_iterator hidden_points_end_internal(std::enable_if_t<Tag::value>* = nullptr) const
   { return _hidden.end(); }
 
   template<typename Tag>
-  void hide_point_internal(const Point& p, typename boost::enable_if_c<Tag::value>::type* = nullptr)
+  void hide_point_internal(const Point& p, std::enable_if_t<Tag::value>* = nullptr)
   { _hidden.push_back(p); }
   template<typename Tag>
-  void unhide_point_internal(const Point_iterator pit, typename boost::enable_if_c<Tag::value>::type* = nullptr)
+  void unhide_point_internal(const Point_iterator pit, std::enable_if_t<Tag::value>* = nullptr)
   { _hidden.erase(pit); }
 
   // Memory_policy is Tag_false ------------------------------------------------
   template<typename Tag>
-  Point_iterator hidden_points_begin_internal(typename boost::disable_if_c<Tag::value>::type* = nullptr)
+  Point_iterator hidden_points_begin_internal(std::enable_if_t<!Tag::value>* = nullptr)
   { return hidden_points_end(); }
   template<typename Tag>
-  Point_iterator hidden_points_end_internal(typename boost::disable_if_c<Tag::value>::type* = nullptr)
+  Point_iterator hidden_points_end_internal(std::enable_if_t<!Tag::value>* = nullptr)
   { return _hidden.end(); }
 
     // const versions
   template<typename Tag>
-  Point_const_iterator hidden_points_begin_internal(typename boost::disable_if_c<Tag::value>::type* = nullptr) const
+  Point_const_iterator hidden_points_begin_internal(std::enable_if_t<!Tag::value>* = nullptr) const
   { return hidden_points_end(); }
   template<typename Tag>
-  Point_const_iterator hidden_points_end_internal(typename boost::disable_if_c<Tag::value>::type* = nullptr) const
+  Point_const_iterator hidden_points_end_internal(std::enable_if_t<!Tag::value>* = nullptr) const
   { return _hidden.end(); }
 
   template<typename Tag>
-  void hide_point_internal(const Point&, typename boost::disable_if_c<Tag::value>::type* = nullptr)
+  void hide_point_internal(const Point&, std::enable_if_t<!Tag::value>* = nullptr)
   { }
   template<typename Tag>
-  void unhide_point_internal(const Point_iterator, typename boost::disable_if_c<Tag::value>::type* = nullptr)
+  void unhide_point_internal(const Point_iterator, std::enable_if_t<!Tag::value>* = nullptr)
   { }
 
   template<typename GT_>
