@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Kernel_23/include/CGAL/Tetrahedron_3.h $
-// $Id: Tetrahedron_3.h 3fa4364 2022-06-10T08:41:19+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_23/include/CGAL/Tetrahedron_3.h $
+// $Id: include/CGAL/Tetrahedron_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -33,7 +33,7 @@ class Tetrahedron_3 : public R_::Kernel_base::Tetrahedron_3
   typedef typename R_::Aff_transformation_3  Aff_transformation_3;
 
   typedef Tetrahedron_3                      Self;
-  CGAL_static_assertion((std::is_same<Self, typename R_::Tetrahedron_3>::value));
+  static_assert(std::is_same<Self, typename R_::Tetrahedron_3>::value);
 
 public:
 
