@@ -2,9 +2,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Polyhedron/include/CGAL/boost/graph/properties_Polyhedron_3_features.h $
-// $Id: properties_Polyhedron_3_features.h 968e9cf 2022-06-16T13:29:20+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polyhedron/include/CGAL/boost/graph/properties_Polyhedron_3_features.h $
+// $Id: include/CGAL/boost/graph/properties_Polyhedron_3_features.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Andreas Fabri
@@ -12,6 +12,9 @@
 #ifndef CGAL_PROPERTIES_POLYHEDRON_3_FEATURES_H
 #define CGAL_PROPERTIES_POLYHEDRON_3_FEATURES_H
 
+#include <CGAL/license/Polyhedron.h>
+
+
 #include <CGAL/Polyhedron_3.h>
 #include <set>
 
